===========
Aggregation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    LazyFrame.count
    LazyFrame.max
    LazyFrame.mean
    LazyFrame.median
    LazyFrame.min
    LazyFrame.null_count
    LazyFrame.quantile
    LazyFrame.std
    LazyFrame.sum
    LazyFrame.var
